@@ -1,6 +1,10 @@
 package Farabi::Plugin::Debug;
 
-our $VERSION = '0.27';
+our $VERSION = '0.29';
+
+sub new {
+	return bless {};
+}
 
 # Returns the plugin's name
 sub plugin_name {
