@@ -9,8 +9,8 @@ $(function() {
 	var currentEditorId;
 	
 	// Cache dialog jQuery references for later use
-	var $about_dialog = $('#about-dialog');
-	var $help_dialog = $("#help-dialog");
+	var $aboutDialog = $('#about-dialog');
+	var $helpDialog = $("#help-dialog");
 	var $perlDocDialog = $("#perl-doc-dialog");
 
 	function displayHelp(cm) {
@@ -186,6 +186,12 @@ $(function() {
 			editor.refresh();
 		});
 
+		// When a tab is shown, let us update current editor id
+		$("#myTab a").on('shown', function() {
+			// Update currentEditorId
+			currentEditorId = "editor" + $(this).attr("href").substring(1);
+		});
+
 		// Run these when we exit this one
 		setTimeout(function() {
 			// focus!
@@ -381,11 +387,11 @@ $(function() {
 		}
 		$('#jquery-version').html($().jquery);
 		$('#codemirror-version').html(CodeMirror.version);
-		$about_dialog.modal("show");
+		$aboutDialog.modal("show");
 	});
 
 	$(document).on('action-help', function() {
-		$help_dialog.modal("show");
+		$helpDialog.modal("show");
 	});
 
 	var onCloseFocusEditor = function () {
